/****************************************************************************
*																			*
* HEADER_START                                                        		*
*                                                                     		*
*		Name:           ST10 Flash drivers for the 0.18um devices      		*
*		Project:                                                       		*
*		Description:    Definition of the Flash control registers      		*
*		Processor:      ST10F27x, F29x, F25x                            	*
*		HW:                                                            		*
*		Revision:       1.4                                           		*
*		Date:           May, 2004                                      		*
*		Compiler:       C crosscompiler Tasking V8.0r2                 		*
*						C crosscompiler Keil uVision2 v2.36					*
*																			*
*		Author:         C. A.                                      			*
*		Company:        ST Microelectronics                            		*
*		                France												*
*		Security:       													*
*																			*
*		Contact:		st10.support@st.com									*
*						http://www.stmcu.com                           		*
* ========================================================================= *
* Copyright (c):      ST Microelectronics.,2004, All rights reserved. 		*
*                                                                     		*
* ========================================================================= *
*
* HEADER_END
*/

/******************************************************************************/
#ifndef F27X_H
#define F27X_H
#define Fcpu_MHz ((unsigned int) 40)
#define F276
#define Tasking	 



/******************************************************************************/

#define	BLANK_WORD		(unsigned long) 0xFFFFFFFF

/****************************************************************/
/*	The following define are specific to the ST10F296 device	*/
#ifdef	F296

#define	Flash_Size6	1					/* Used in C file. Indicates the size of Flash as in device name */

#define MAX_IFLASH_ADDRESS	(unsigned long)0x0008FFFE
#define	MAX_XFLASH_ADDRESS	(unsigned long)0x000DFFFE
#define	MAX_FLASH_ADDRESS	(unsigned long)0x000DFFFE
#define FLASH_MAX_BANKS		3
#define	FLASH_MAX_MODULE	1
#define FLASH_MAX_SECTORS	16
#define XMODULE_FIRST_BANK	2

#define	BANK0_START				(unsigned long)0x00010000
#define BANK0_WORDCOUNT			(unsigned long)0x00018000			// 384kByte
#define	BANK0_SECTOR0_START		(unsigned long)0x00010000
#define BANK0_SECTOR0_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR1_START		(unsigned long)0x00012000
#define BANK0_SECTOR1_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR2_START		(unsigned long)0x00014000
#define BANK0_SECTOR2_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR3_START		(unsigned long)0x00016000
#define	BANK0_SECTOR3_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR4_START		(unsigned long)0x00018000
#define BANK0_SECTOR4_WORDCOUNT	(unsigned long)0x00002000			// 32 KByte
#define	BANK0_SECTOR5_START		(unsigned long)0x00020000
#define BANK0_SECTOR5_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR6_START		(unsigned long)0x00030000
#define BANK0_SECTOR6_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR7_START		(unsigned long)0x00040000
#define BANK0_SECTOR7_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR8_START		(unsigned long)0x00050000
#define BANK0_SECTOR8_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR9_START		(unsigned long)0x00060000
#define BANK0_SECTOR9_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK1_START				(unsigned long)0x00070000
#define BANK1_WORDCOUNT			(unsigned long)0x00008000			// 128 KByte
#define	BANK1_SECTOR0_START		(unsigned long)0x00070000
#define BANK1_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK1_SECTOR1_START		(unsigned long)0x00080000
#define BANK1_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK2_START				(unsigned long)0x00090000
#define BANK2_WORDCOUNT			(unsigned long)0x0000C000			// 192 KByte
#define	BANK2_SECTOR0_START		(unsigned long)0x00090000
#define BANK2_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK2_SECTOR1_START		(unsigned long)0x000A0000
#define BANK2_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK2_SECTOR2_START		(unsigned long)0x000B0000
#define BANK2_SECTOR2_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK3_START				(unsigned long)0x000C0000
#define BANK3_WORDCOUNT			(unsigned long)0x00008000			// 128 KByte
#define	BANK3_SECTOR0_START		(unsigned long)0x000C0000
#define BANK3_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK3_SECTOR1_START		(unsigned long)0x000D0000
#define BANK3_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#ifdef Tasking		// Flash Registers definitions for the Tasking Toolchain

/* Flash control registers of the F286 derivative */
#define	FCR0L		*(_huge unsigned int *)(0x000E0000)
#define	FCR0H		*(_huge unsigned int *)(0x000E0002)
#define	FCR1L		*(_huge unsigned int *)(0x000E0004)
#define	FCR1H		*(_huge unsigned int *)(0x000E0006)

/* Flash data registers */
#define	FDR0L		*(_huge unsigned int *)(0x000E0008)
#define	FDR0H		*(_huge unsigned int *)(0x000E000A)
#define	FDR1L		*(_huge unsigned int *)(0x000E000C)
#define	FD1RH		*(_huge unsigned int *)(0x000E000E)

#define	FDR0		*(_huge unsigned long *)(0x000E0008)
#define	FDR1		*(_huge unsigned long *)(0x000E000C)

/* Flash address registers */
#define	FARL		*(_huge unsigned int *)(0x000E0010)
#define	FARH		*(_huge unsigned int *)(0x000E0012)

#define	FAR			*(_huge unsigned long *)(0x000E0010)

/* Flash error register */
#define	FER			*(_huge unsigned int *)(0x000E0014)

#elif Keil		// Flash Registers definitions for the Keil Toolchain
/* Flash control registers of the F286 derivative */
#define	FCR0L		*( unsigned int huge *)(0x000E0000)
#define	FCR0H		*( unsigned int huge *)(0x000E0002)
#define	FCR1L		*( unsigned int huge *)(0x000E0004)
#define	FCR1H		*( unsigned int huge *)(0x000E0006)

/* Flash data registers */
#define	FDR0L		*( unsigned int huge *)(0x000E0008)
#define	FDR0H		*( unsigned int huge *)(0x000E000A)
#define	FDR1L		*( unsigned int huge *)(0x000E000C)
#define	FD1RH		*( unsigned int huge *)(0x000E000E)

#define	FDR0		*( unsigned long huge *)(0x000E0008)
#define	FDR1		*( unsigned long huge *)(0x000E000C)

/* Flash address registers */
#define	FARL		*( unsigned int huge *)(0x000E0010)
#define	FARH		*( unsigned int huge *)(0x000E0012)

#define	FAR			*( unsigned long huge *)(0x000E0010)

/* Flash error register */
#define	FER			*( unsigned int huge *)(0x000E0014)

#endif		// Tasking - Keil selection

/************************************************************/
/*   DEFINITION OF THE MAKS NEEDED 							*/
/*	Equivalent to the bit definition of each Flash register	*/
/************************************************************/

/*	FCR0L	*/
#define	F_bsy2			0x0002             /* Bank 2 busy    */ 
#define	F_bsy3			0x0004             /* Bank 3 busy    */ 
#define	F_lock			0x0010             /* Flash register access locked */
#define	F_bsy0			0x0020             /* Bank 0 busy    */
#define	F_bsy1			0x0040             /* Bank 1 busy    */

/*	FCR0H	*/
#define	F_Ismod		(unsigned int)	0x0080
#define	F_Xsmod		(unsigned int)	0xFF7F

#define	F_smod		(unsigned int)	0x0080				/* Select Module		*/
#define F_spr		(unsigned int)	0x0100				/* Set protection		*/
#define	F_ser		(unsigned int)	0x0800				/* Sector Erase			*/
#define	F_dwpg		(unsigned int)	0x1000				/* Double Word Program	*/
#define	F_wpg		(unsigned int)	0x2000				/* Word Program			*/
#define F_susp		(unsigned int)	0x4000				/* Suspend				*/
#define	F_wms		(unsigned int)	0x8000				/* Write Mode Start		*/

/*	FCR1L	*/
#define	F_b2f0		(unsigned int)	0x0001				/* Bank2 Flash Sector 0 Status-Select	*/
#define	F_b2f1		(unsigned int)	0x0002				/* Bank2 Flash Sector 1 Status-Select	*/
#define	F_b2f2		(unsigned int)	0x0004				/* Bank2 Flash Sector 2 Status-Select	*/
#define	F_b2all		(unsigned int)	0x0007				/* Bank2 All Sectors					*/

#define	F_b0f0		(unsigned int)	0x0001				/* Bank0 Flash Sector 0 Status-Select	*/
#define	F_b0f1		(unsigned int)	0x0002				/* Bank0 Flash Sector 1 Status-Select	*/
#define	F_b0f2		(unsigned int)	0x0004				/* Bank0 Flash Sector 2 Status-Select	*/
#define	F_b0f3		(unsigned int)	0x0008				/* Bank0 Flash Sector 3 Status-Select	*/
#define	F_b0f4		(unsigned int)	0x0010				/* Bank0 Flash Sector 4 Status-Select	*/
#define	F_b0f5		(unsigned int)	0x0020				/* Bank0 Flash Sector 5 Status-Select	*/
#define	F_b0f6		(unsigned int)	0x0040				/* Bank0 Flash Sector 6 Status-Select	*/
#define	F_b0f7		(unsigned int)	0x0080				/* Bank0 Flash Sector 7 Status-Select	*/
#define	F_b0f8		(unsigned int)	0x0100				/* Bank0 Flash Sector 8 Status-Select	*/
#define F_b0f9		(unsigned int)	0x0200				/* Bank0 Flash Sector 9 Status-Select	*/
#define	F_b0all		(unsigned int)	0x03FF				/* Bank0 All Sectors					*/

/*	FCR1H	*/
#define	F_b3S		(unsigned int)	0x0200				/* Flash Bank3 Status	*/
#define	F_b2S		(unsigned int)	0x0100				/* Flash Bank2 Status	*/
#define	F_b3f1		(unsigned int)	0x0002				/* Bank3 Flash Sector 1 Status-Select	*/
#define	F_b3f0		(unsigned int)	0x0001				/* Bank3 Flash Sector 0 Status-Select	*/
#define	F_b3all		(unsigned int)	0x0003				/* Bank3 All Sectors					*/

#define	F_b1S		(unsigned int)	0x0200				/* Flash Bank1 Status	*/
#define	F_b0S		(unsigned int)	0x0100				/* Flash Bank0 Status	*/
#define	F_b1f1		(unsigned int)	0x0002				/* Bank1 Flash Sector 1 Status-Select	*/
#define	F_b1f0		(unsigned int)	0x0001				/* Bank1 Flash Sector 0 Status-Select	*/
#define	F_b1all		(unsigned int)	0x0003				/* Bank1 All Sectors					*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

#endif		/* End of F296 specific defines */
/******************************************************************************/


/********************************************************************/
/*	The following define are specific to the ST10F293xxx devices	*/
/*		No XFlash compared to F296		*/
#ifdef	F293

#define	Flash_Size3	1					/* Used in C file. Indicates the size of Flash as in device name */

#define MAX_IFLASH_ADDRESS	(unsigned long)0x0008FFFE
#define	MAX_FLASH_ADDRESS	(unsigned long)0x0008FFFE
#define FLASH_MAX_BANKS		1
#define	FLASH_MAX_MODULE	0
#define FLASH_MAX_SECTORS	12

#define	BANK0_START				(unsigned long)0x00010000
#define BANK0_WORDCOUNT			(unsigned long)0x00018000			// 384kByte
#define	BANK0_SECTOR0_START		(unsigned long)0x00010000
#define BANK0_SECTOR0_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR1_START		(unsigned long)0x00012000
#define BANK0_SECTOR1_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR2_START		(unsigned long)0x00014000
#define BANK0_SECTOR2_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR3_START		(unsigned long)0x00016000
#define	BANK0_SECTOR3_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR4_START		(unsigned long)0x00018000
#define BANK0_SECTOR4_WORDCOUNT	(unsigned long)0x00002000			// 32 KByte
#define	BANK0_SECTOR5_START		(unsigned long)0x00020000
#define BANK0_SECTOR5_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR6_START		(unsigned long)0x00030000
#define BANK0_SECTOR6_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR7_START		(unsigned long)0x00040000
#define BANK0_SECTOR7_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR8_START		(unsigned long)0x00050000
#define BANK0_SECTOR8_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR9_START		(unsigned long)0x00060000
#define BANK0_SECTOR9_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK1_START				(unsigned long)0x00070000
#define BANK1_WORDCOUNT			(unsigned long)0x00008000			// 128 KByte
#define	BANK1_SECTOR0_START		(unsigned long)0x00070000
#define BANK1_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK1_SECTOR1_START		(unsigned long)0x00080000
#define BANK1_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#ifdef Tasking
/* Flash control registers of the F273xx derivatives */
#define	FCR0L		*(_huge unsigned int *)(0x000E0000)
#define	FCR0H		*(_huge unsigned int *)(0x000E0002)
#define	FCR1L		*(_huge unsigned int *)(0x000E0004)
#define	FCR1H		*(_huge unsigned int *)(0x000E0006)

/* Flash data registers */
#define	FDR0L		*(_huge unsigned int *)(0x000E0008)
#define	FDR0H		*(_huge unsigned int *)(0x000E000A)
#define	FDR1L		*(_huge unsigned int *)(0x000E000C)
#define	FD1RH		*(_huge unsigned int *)(0x000E000E)

#define	FDR0		*(_huge unsigned long *)(0x000E0008)
#define	FDR1		*(_huge unsigned long *)(0x000E000C)

/* Flash address registers */
#define	FARL		*(_huge unsigned int *)(0x000E0010)
#define	FARH		*(_huge unsigned int *)(0x000E0012)

#define	FAR			*(_huge unsigned long *)(0x000E0010)

/* Flash error register */
#define	FER			*(_huge unsigned int *)(0x000E0014)

#elif Keil
/* Flash control registers of the F293xx derivatives */
#define	FCR0L		*( unsigned int huge *)(0x000E0000)
#define	FCR0H		*( unsigned int huge *)(0x000E0002)
#define	FCR1L		*( unsigned int huge *)(0x000E0004)
#define	FCR1H		*( unsigned int huge *)(0x000E0006)

/* Flash data registers */
#define	FDR0L		*( unsigned int huge *)(0x000E0008)
#define	FDR0H		*( unsigned int huge *)(0x000E000A)
#define	FDR1L		*( unsigned int huge *)(0x000E000C)
#define	FD1RH		*( unsigned int huge *)(0x000E000E)

#define	FDR0		*( unsigned long huge *)(0x000E0008)
#define	FDR1		*( unsigned long huge *)(0x000E000C)

/* Flash address registers */
#define	FARL		*( unsigned int huge *)(0x000E0010)
#define	FARH		*( unsigned int huge *)(0x000E0012)

#define	FAR			*( unsigned long huge *)(0x000E0010)

/* Flash error register */
#define	FER			*( unsigned int huge *)(0x000E0014)

#endif		// Tasking - Keil selection

/*	FCR0L	*/
#define	F_lock			0x0010             /* Flash register access locked */
#define	F_bsy0			0x0020             /* Bank 0 busy    */
#define	F_bsy1			0x0040             /* Bank 1 busy    */

/*	FCR0H	*/
#define	F_Ismod		(unsigned int)	0x0080

#define	F_smod		(unsigned int)	0x0080				/* Select Module		*/
#define F_spr		(unsigned int)	0x0100				/* Set protection		*/
#define	F_ser		(unsigned int)	0x0800				/* Sector Erase			*/
#define	F_dwpg		(unsigned int)	0x1000				/* Double Word Program	*/
#define	F_wpg		(unsigned int)	0x2000				/* Word Program			*/
#define F_susp		(unsigned int)	0x4000				/* Suspend				*/
#define	F_wms		(unsigned int)	0x8000				/* Write Mode Start		*/

/*	FCR1L	*/
#define	F_b2f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f2		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0f0		(unsigned int)	0x0001				/* Bank0 Flash Sector 0 Status-Select	*/
#define	F_b0f1		(unsigned int)	0x0002				/* Bank0 Flash Sector 1 Status-Select	*/
#define	F_b0f2		(unsigned int)	0x0004				/* Bank0 Flash Sector 2 Status-Select	*/
#define	F_b0f3		(unsigned int)	0x0008				/* Bank0 Flash Sector 3 Status-Select	*/
#define	F_b0f4		(unsigned int)	0x0010				/* Bank0 Flash Sector 4 Status-Select	*/
#define	F_b0f5		(unsigned int)	0x0020				/* Bank0 Flash Sector 5 Status-Select	*/
#define	F_b0f6		(unsigned int)	0x0040				/* Bank0 Flash Sector 6 Status-Select	*/
#define	F_b0f7		(unsigned int)	0x0080				/* Bank0 Flash Sector 7 Status-Select	*/
#define	F_b0f8		(unsigned int)	0x0100				/* Bank0 Flash Sector 8 Status-Select	*/
#define F_b0f9		(unsigned int)	0x0200				/* Bank0 Flash Sector 9 Status-Select	*/
#define	F_b0all		(unsigned int)	0x03FF				/* Bank0 All Sectors					*/

/*	FCR1H	*/
#define	F_b3f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b1S		(unsigned int)	0x0200				/* Flash Bank1 Status	*/
#define	F_b0S		(unsigned int)	0x0100				/* Flash Bank0 Status	*/
#define	F_b1f1		(unsigned int)	0x0002				/* Bank1 Flash Sector 1 Status-Select	*/
#define	F_b1f0		(unsigned int)	0x0001				/* Bank1 Flash Sector 0 Status-Select	*/
#define	F_b1all		(unsigned int)	0x0003				/* Bank1 All Sectors					*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

#endif		/* End of F293 specific defines */
/********************************************************************/




/****************************************************************/
/*	The following define are specific to the ST10F276 device	*/
#ifdef	F276

#define	Flash_Size6	1					/* Used in C file. Indicates the size of Flash as in device name */

#define MAX_IFLASH_ADDRESS	(unsigned long)0x0008FFFE
#define	MAX_XFLASH_ADDRESS	(unsigned long)0x000DFFFE
#define	MAX_FLASH_ADDRESS	(unsigned long)0x000DFFFE
#define FLASH_MAX_BANKS		3
#define	FLASH_MAX_MODULE	1
#define FLASH_MAX_SECTORS	16
#define XMODULE_FIRST_BANK	2

#define	BANK0_START				(unsigned long)0x00010000
#define BANK0_WORDCOUNT			(unsigned long)0x00018000			// 384kByte
#define	BANK0_SECTOR0_START		(unsigned long)0x00010000
#define BANK0_SECTOR0_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR1_START		(unsigned long)0x00012000
#define BANK0_SECTOR1_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR2_START		(unsigned long)0x00014000
#define BANK0_SECTOR2_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR3_START		(unsigned long)0x00016000
#define	BANK0_SECTOR3_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR4_START		(unsigned long)0x00018000
#define BANK0_SECTOR4_WORDCOUNT	(unsigned long)0x00002000			// 32 KByte
#define	BANK0_SECTOR5_START		(unsigned long)0x00020000
#define BANK0_SECTOR5_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR6_START		(unsigned long)0x00030000
#define BANK0_SECTOR6_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR7_START		(unsigned long)0x00040000
#define BANK0_SECTOR7_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR8_START		(unsigned long)0x00050000
#define BANK0_SECTOR8_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR9_START		(unsigned long)0x00060000
#define BANK0_SECTOR9_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK1_START				(unsigned long)0x00070000
#define BANK1_WORDCOUNT			(unsigned long)0x00008000			// 128 KByte
#define	BANK1_SECTOR0_START		(unsigned long)0x00070000
#define BANK1_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK1_SECTOR1_START		(unsigned long)0x00080000
#define BANK1_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK2_START				(unsigned long)0x00090000
#define BANK2_WORDCOUNT			(unsigned long)0x0000C000			// 192 KByte
#define	BANK2_SECTOR0_START		(unsigned long)0x00090000
#define BANK2_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK2_SECTOR1_START		(unsigned long)0x000A0000
#define BANK2_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK2_SECTOR2_START		(unsigned long)0x000B0000
#define BANK2_SECTOR2_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK3_START				(unsigned long)0x000C0000
#define BANK3_WORDCOUNT			(unsigned long)0x00008000			// 128 KByte
#define	BANK3_SECTOR0_START		(unsigned long)0x000C0000
#define BANK3_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK3_SECTOR1_START		(unsigned long)0x000D0000
#define BANK3_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#ifdef Tasking
/* Flash control registers of the F276xx derivatives */
#define	FCR0L		*(_huge unsigned int *)(0x000E0000)
#define	FCR0H		*(_huge unsigned int *)(0x000E0002)
#define	FCR1L		*(_huge unsigned int *)(0x000E0004)
#define	FCR1H		*(_huge unsigned int *)(0x000E0006)

/* Flash data registers */
#define	FDR0L		*(_huge unsigned int *)(0x000E0008)
#define	FDR0H		*(_huge unsigned int *)(0x000E000A)
#define	FDR1L		*(_huge unsigned int *)(0x000E000C)
#define	FD1RH		*(_huge unsigned int *)(0x000E000E)

#define	FDR0		*(_huge unsigned long *)(0x000E0008)
#define	FDR1		*(_huge unsigned long *)(0x000E000C)

/* Flash address registers */
#define	FARL		*(_huge unsigned int *)(0x000E0010)
#define	FARH		*(_huge unsigned int *)(0x000E0012)

#define	FAR			*(_huge unsigned long *)(0x000E0010)

/* Flash error register */
#define	FER			*(_huge unsigned int *)(0x000E0014)

#elif Keil
/* Flash control registers of the F276xx derivatives */
#define	FCR0L		*(unsigned int huge *)0x000E0000
#define	FCR0H		*(unsigned int huge *)0x000E0002
#define	FCR1L		*(unsigned int huge *)0x000E0004
#define	FCR1H		*(unsigned int huge *)0x000E0006

/* Flash data registers */
#define	FDR0L		*( unsigned int huge *)(0x000E0008)
#define	FDR0H		*( unsigned int huge *)(0x000E000A)
#define	FDR1L		*( unsigned int huge *)(0x000E000C)
#define	FD1RH		*( unsigned int huge *)(0x000E000E)

#define	FDR0		*( unsigned long huge *)(0x000E0008)
#define	FDR1		*( unsigned long huge *)(0x000E000C)

/* Flash address registers */
#define	FARL		*( unsigned int huge *)(0x000E0010)
#define	FARH		*( unsigned int huge *)(0x000E0012)

#define	FAR			*( unsigned long huge *)(0x000E0010)

/* Flash error register */
#define	FER			*( unsigned int huge *)(0x000E0014)

#endif		// Tasking - Keil selection

/************************************************************/
/*   DEFINITION OF THE MAKS NEEDED 							*/
/*	Equivalent to the bit definition of each Flash register	*/
/************************************************************/

/*	FCR0L	*/
#define	F_bsy2			0x0002             /* Bank 2 busy    */ 
#define	F_bsy3			0x0004             /* Bank 3 busy    */ 
#define	F_lock			0x0010             /* Flash register access locked */
#define	F_bsy0			0x0020             /* Bank 0 busy    */
#define	F_bsy1			0x0040             /* Bank 1 busy    */

/*	FCR0H	*/
#define	F_Ismod		(unsigned int)	0x0080
#define	F_Xsmod		(unsigned int)	0xFF7F

#define	F_smod		(unsigned int)	0x0080				/* Select Module		*/
#define F_spr		(unsigned int)	0x0100				/* Set protection		*/
#define	F_ser		(unsigned int)	0x0800				/* Sector Erase			*/
#define	F_dwpg		(unsigned int)	0x1000				/* Double Word Program	*/
#define	F_wpg		(unsigned int)	0x2000				/* Word Program			*/
#define F_susp		(unsigned int)	0x4000				/* Suspend				*/
#define	F_wms		(unsigned int)	0x8000				/* Write Mode Start		*/

/*	FCR1L	*/
#define	F_b2f0		(unsigned int)	0x0001				/* Bank2 Flash Sector 0 Status-Select	*/
#define	F_b2f1		(unsigned int)	0x0002				/* Bank2 Flash Sector 1 Status-Select	*/
#define	F_b2f2		(unsigned int)	0x0004				/* Bank2 Flash Sector 2 Status-Select	*/
#define	F_b2all		(unsigned int)	0x0007				/* Bank2 All Sectors					*/

#define	F_b0f0		(unsigned int)	0x0001				/* Bank0 Flash Sector 0 Status-Select	*/
#define	F_b0f1		(unsigned int)	0x0002				/* Bank0 Flash Sector 1 Status-Select	*/
#define	F_b0f2		(unsigned int)	0x0004				/* Bank0 Flash Sector 2 Status-Select	*/
#define	F_b0f3		(unsigned int)	0x0008				/* Bank0 Flash Sector 3 Status-Select	*/
#define	F_b0f4		(unsigned int)	0x0010				/* Bank0 Flash Sector 4 Status-Select	*/
#define	F_b0f5		(unsigned int)	0x0020				/* Bank0 Flash Sector 5 Status-Select	*/
#define	F_b0f6		(unsigned int)	0x0040				/* Bank0 Flash Sector 6 Status-Select	*/
#define	F_b0f7		(unsigned int)	0x0080				/* Bank0 Flash Sector 7 Status-Select	*/
#define	F_b0f8		(unsigned int)	0x0100				/* Bank0 Flash Sector 8 Status-Select	*/
#define F_b0f9		(unsigned int)	0x0200				/* Bank0 Flash Sector 9 Status-Select	*/
#define	F_b0all		(unsigned int)	0x03FF				/* Bank0 All Sectors					*/

/*	FCR1H	*/
#define	F_b3S		(unsigned int)	0x0200				/* Flash Bank3 Status	*/
#define	F_b2S		(unsigned int)	0x0100				/* Flash Bank2 Status	*/
#define	F_b3f1		(unsigned int)	0x0002				/* Bank3 Flash Sector 1 Status-Select	*/
#define	F_b3f0		(unsigned int)	0x0001				/* Bank3 Flash Sector 0 Status-Select	*/
#define	F_b3all		(unsigned int)	0x0003				/* Bank3 All Sectors					*/

#define	F_b1S		(unsigned int)	0x0200				/* Flash Bank1 Status	*/
#define	F_b0S		(unsigned int)	0x0100				/* Flash Bank0 Status	*/
#define	F_b1f1		(unsigned int)	0x0002				/* Bank1 Flash Sector 1 Status-Select	*/
#define	F_b1f0		(unsigned int)	0x0001				/* Bank1 Flash Sector 0 Status-Select	*/
#define	F_b1all		(unsigned int)	0x0003				/* Bank1 All Sectors					*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

#endif		/* End of F276 specific defines */
/******************************************************************************/

/********************************************************************/
/*	The following define are specific to the ST10F275xxx devices	*/
/* No Bank3 compared to F276	*/
#ifdef	F275

#define	Flash_Size5	1					/* Used in C file. Indicates the size of Flash as in device name */

#define MAX_IFLASH_ADDRESS	(unsigned long)0x0008FFFE
#define	MAX_XFLASH_ADDRESS	(unsigned long)0x000DFFFE
#define	MAX_FLASH_ADDRESS	(unsigned long)0x000DFFFE
#define FLASH_MAX_BANKS		2
#define	FLASH_MAX_MODULE	1
#define FLASH_MAX_SECTORS	14
#define XMODULE_FIRST_BANK	2

#define	BANK0_START				(unsigned long)0x00010000
#define BANK0_WORDCOUNT			(unsigned long)0x00018000			// 384kByte
#define	BANK0_SECTOR0_START		(unsigned long)0x00010000
#define BANK0_SECTOR0_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR1_START		(unsigned long)0x00012000
#define BANK0_SECTOR1_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR2_START		(unsigned long)0x00014000
#define BANK0_SECTOR2_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR3_START		(unsigned long)0x00016000
#define	BANK0_SECTOR3_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR4_START		(unsigned long)0x00018000
#define BANK0_SECTOR4_WORDCOUNT	(unsigned long)0x00002000			// 32 KByte
#define	BANK0_SECTOR5_START		(unsigned long)0x00020000
#define BANK0_SECTOR5_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR6_START		(unsigned long)0x00030000
#define BANK0_SECTOR6_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR7_START		(unsigned long)0x00040000
#define BANK0_SECTOR7_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR8_START		(unsigned long)0x00050000
#define BANK0_SECTOR8_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR9_START		(unsigned long)0x00060000
#define BANK0_SECTOR9_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK1_START				(unsigned long)0x00070000
#define BANK1_WORDCOUNT			(unsigned long)0x00008000			// 128 KByte
#define	BANK1_SECTOR0_START		(unsigned long)0x00070000
#define BANK1_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK1_SECTOR1_START		(unsigned long)0x00080000
#define BANK1_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK2_START				(unsigned long)0x00090000
#define BANK2_WORDCOUNT			(unsigned long)0x0000C000			// 192 KByte
#define	BANK2_SECTOR0_START		(unsigned long)0x00090000
#define BANK2_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK2_SECTOR1_START		(unsigned long)0x000A0000
#define BANK2_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK2_SECTOR2_START		(unsigned long)0x000B0000
#define BANK2_SECTOR2_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#ifdef Tasking
/* Flash control registers of the F275xx derivatives */
#define	FCR0L		*(_huge unsigned int *)(0x000E0000)
#define	FCR0H		*(_huge unsigned int *)(0x000E0002)
#define	FCR1L		*(_huge unsigned int *)(0x000E0004)
#define	FCR1H		*(_huge unsigned int *)(0x000E0006)

/* Flash data registers */
#define	FDR0L		*(_huge unsigned int *)(0x000E0008)
#define	FDR0H		*(_huge unsigned int *)(0x000E000A)
#define	FDR1L		*(_huge unsigned int *)(0x000E000C)
#define	FD1RH		*(_huge unsigned int *)(0x000E000E)

#define	FDR0		*(_huge unsigned long *)(0x000E0008)
#define	FDR1		*(_huge unsigned long *)(0x000E000C)

/* Flash address registers */
#define	FARL		*(_huge unsigned int *)(0x000E0010)
#define	FARH		*(_huge unsigned int *)(0x000E0012)

#define	FAR			*(_huge unsigned long *)(0x000E0010)

/* Flash error register */
#define	FER			*(_huge unsigned int *)(0x000E0014)

#elif Keil
/* Flash control registers of the F275xx derivatives */
#define	FCR0L		*( unsigned int huge *)(0x000E0000)
#define	FCR0H		*( unsigned int huge *)(0x000E0002)
#define	FCR1L		*( unsigned int huge *)(0x000E0004)
#define	FCR1H		*( unsigned int huge *)(0x000E0006)

/* Flash data registers */
#define	FDR0L		*( unsigned int huge *)(0x000E0008)
#define	FDR0H		*( unsigned int huge *)(0x000E000A)
#define	FDR1L		*( unsigned int huge *)(0x000E000C)
#define	FD1RH		*( unsigned int huge *)(0x000E000E)

#define	FDR0		*( unsigned long huge *)(0x000E0008)
#define	FDR1		*( unsigned long huge *)(0x000E000C)

/* Flash address registers */
#define	FARL		*( unsigned int huge *)(0x000E0010)
#define	FARH		*( unsigned int huge *)(0x000E0012)

#define	FAR			*( unsigned long huge *)(0x000E0010)

/* Flash error register */
#define	FER			*( unsigned int huge *)(0x000E0014)

#endif		// Tasking - Keil selection

/************************************************************/
/*   DEFINITION OF THE MAKS NEEDED 							*/
/*	Equivalent to the bit definition of each Flash register	*/
/************************************************************/

/*	FCR0L	*/
#define	F_bsy2			0x0002             /* Bank 2 busy    */ 
#define	F_lock			0x0010             /* Flash register access locked */
#define	F_bsy0			0x0020             /* Bank 0 busy    */
#define	F_bsy1			0x0040             /* Bank 1 busy    */

/*	FCR0H	*/
#define	F_Ismod		(unsigned int)	0x0080
#define	F_Xsmod		(unsigned int)	0xFF7F

#define	F_smod		(unsigned int)	0x0080				/* Select Module		*/
#define F_spr		(unsigned int)	0x0100				/* Set protection		*/
#define	F_ser		(unsigned int)	0x0800				/* Sector Erase			*/
#define	F_dwpg		(unsigned int)	0x1000				/* Double Word Program	*/
#define	F_wpg		(unsigned int)	0x2000				/* Word Program			*/
#define F_susp		(unsigned int)	0x4000				/* Suspend				*/
#define	F_wms		(unsigned int)	0x8000				/* Write Mode Start		*/

/*	FCR1L	*/
#define	F_b2f0		(unsigned int)	0x0001				/* Bank2 Flash Sector 0 Status-Select	*/
#define	F_b2f1		(unsigned int)	0x0002				/* Bank2 Flash Sector 1 Status-Select	*/
#define	F_b2f2		(unsigned int)	0x0004				/* Bank2 Flash Sector 2 Status-Select	*/
#define	F_b2all		(unsigned int)	0x0007				/* Bank2 All Sectors					*/

#define	F_b0f0		(unsigned int)	0x0001				/* Bank0 Flash Sector 0 Status-Select	*/
#define	F_b0f1		(unsigned int)	0x0002				/* Bank0 Flash Sector 1 Status-Select	*/
#define	F_b0f2		(unsigned int)	0x0004				/* Bank0 Flash Sector 2 Status-Select	*/
#define	F_b0f3		(unsigned int)	0x0008				/* Bank0 Flash Sector 3 Status-Select	*/
#define	F_b0f4		(unsigned int)	0x0010				/* Bank0 Flash Sector 4 Status-Select	*/
#define	F_b0f5		(unsigned int)	0x0020				/* Bank0 Flash Sector 5 Status-Select	*/
#define	F_b0f6		(unsigned int)	0x0040				/* Bank0 Flash Sector 6 Status-Select	*/
#define	F_b0f7		(unsigned int)	0x0080				/* Bank0 Flash Sector 7 Status-Select	*/
#define	F_b0f8		(unsigned int)	0x0100				/* Bank0 Flash Sector 8 Status-Select	*/
#define F_b0f9		(unsigned int)	0x0200				/* Bank0 Flash Sector 9 Status-Select	*/
#define	F_b0all		(unsigned int)	0x03FF				/* Bank0 All Sectors					*/

/*	FCR1H	*/
#define	F_b2S		(unsigned int)	0x0100				/* Flash Bank2 Status	*/
#define	F_b3f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b1S		(unsigned int)	0x0200				/* Flash Bank1 Status	*/
#define	F_b0S		(unsigned int)	0x0100				/* Flash Bank0 Status	*/
#define	F_b1f1		(unsigned int)	0x0002				/* Bank1 Flash Sector 1 Status-Select	*/
#define	F_b1f0		(unsigned int)	0x0001				/* Bank1 Flash Sector 0 Status-Select	*/
#define	F_b1all		(unsigned int)	0x0003				/* Bank1 All Sectors					*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

#endif		/* End of F275 specific defines */
/********************************************************************/

/********************************************************************/
/*	The following define are specific to the ST10F273xxx devices	*/
/*		No XFlash compared to F276		*/
#ifdef	F273

#define	Flash_Size3	1					/* Used in C file. Indicates the size of Flash as in device name */

#define MAX_IFLASH_ADDRESS	(unsigned long)0x0008FFFE
#define	MAX_FLASH_ADDRESS	(unsigned long)0x0008FFFE
#define FLASH_MAX_BANKS		1
#define	FLASH_MAX_MODULE	0
#define FLASH_MAX_SECTORS	12

#define	BANK0_START				(unsigned long)0x00010000
#define BANK0_WORDCOUNT			(unsigned long)0x00018000			// 384kByte
#define	BANK0_SECTOR0_START		(unsigned long)0x00010000
#define BANK0_SECTOR0_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR1_START		(unsigned long)0x00012000
#define BANK0_SECTOR1_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR2_START		(unsigned long)0x00014000
#define BANK0_SECTOR2_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR3_START		(unsigned long)0x00016000
#define	BANK0_SECTOR3_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR4_START		(unsigned long)0x00018000
#define BANK0_SECTOR4_WORDCOUNT	(unsigned long)0x00002000			// 32 KByte
#define	BANK0_SECTOR5_START		(unsigned long)0x00020000
#define BANK0_SECTOR5_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR6_START		(unsigned long)0x00030000
#define BANK0_SECTOR6_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR7_START		(unsigned long)0x00040000
#define BANK0_SECTOR7_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR8_START		(unsigned long)0x00050000
#define BANK0_SECTOR8_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR9_START		(unsigned long)0x00060000
#define BANK0_SECTOR9_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#define	BANK1_START				(unsigned long)0x00070000
#define BANK1_WORDCOUNT			(unsigned long)0x00008000			// 128 KByte
#define	BANK1_SECTOR0_START		(unsigned long)0x00070000
#define BANK1_SECTOR0_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK1_SECTOR1_START		(unsigned long)0x00080000
#define BANK1_SECTOR1_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#ifdef Tasking
/* Flash control registers of the F273xx derivatives */
#define	FCR0L		*(_huge unsigned int *)(0x000E0000)
#define	FCR0H		*(_huge unsigned int *)(0x000E0002)
#define	FCR1L		*(_huge unsigned int *)(0x000E0004)
#define	FCR1H		*(_huge unsigned int *)(0x000E0006)

/* Flash data registers */
#define	FDR0L		*(_huge unsigned int *)(0x000E0008)
#define	FDR0H		*(_huge unsigned int *)(0x000E000A)
#define	FDR1L		*(_huge unsigned int *)(0x000E000C)
#define	FD1RH		*(_huge unsigned int *)(0x000E000E)

#define	FDR0		*(_huge unsigned long *)(0x000E0008)
#define	FDR1		*(_huge unsigned long *)(0x000E000C)

/* Flash address registers */
#define	FARL		*(_huge unsigned int *)(0x000E0010)
#define	FARH		*(_huge unsigned int *)(0x000E0012)

#define	FAR			*(_huge unsigned long *)(0x000E0010)

/* Flash error register */
#define	FER			*(_huge unsigned int *)(0x000E0014)

#elif Keil
/* Flash control registers of the F273xx derivatives */
#define	FCR0L		*( unsigned int huge *)(0x000E0000)
#define	FCR0H		*( unsigned int huge *)(0x000E0002)
#define	FCR1L		*( unsigned int huge *)(0x000E0004)
#define	FCR1H		*( unsigned int huge *)(0x000E0006)

/* Flash data registers */
#define	FDR0L		*( unsigned int huge *)(0x000E0008)
#define	FDR0H		*( unsigned int huge *)(0x000E000A)
#define	FDR1L		*( unsigned int huge *)(0x000E000C)
#define	FD1RH		*( unsigned int huge *)(0x000E000E)

#define	FDR0		*( unsigned long huge *)(0x000E0008)
#define	FDR1		*( unsigned long huge *)(0x000E000C)

/* Flash address registers */
#define	FARL		*( unsigned int huge *)(0x000E0010)
#define	FARH		*( unsigned int huge *)(0x000E0012)

#define	FAR			*( unsigned long huge *)(0x000E0010)

/* Flash error register */
#define	FER			*( unsigned int huge *)(0x000E0014)

#endif		// Tasking - Keil selection

/*	FCR0L	*/
#define	F_lock			0x0010             /* Flash register access locked */
#define	F_bsy0			0x0020             /* Bank 0 busy    */
#define	F_bsy1			0x0040             /* Bank 1 busy    */

/*	FCR0H	*/
#define	F_Ismod		(unsigned int)	0x0080

#define	F_smod		(unsigned int)	0x0080				/* Select Module		*/
#define F_spr		(unsigned int)	0x0100				/* Set protection		*/
#define	F_ser		(unsigned int)	0x0800				/* Sector Erase			*/
#define	F_dwpg		(unsigned int)	0x1000				/* Double Word Program	*/
#define	F_wpg		(unsigned int)	0x2000				/* Word Program			*/
#define F_susp		(unsigned int)	0x4000				/* Suspend				*/
#define	F_wms		(unsigned int)	0x8000				/* Write Mode Start		*/

/*	FCR1L	*/
#define	F_b2f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f2		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0f0		(unsigned int)	0x0001				/* Bank0 Flash Sector 0 Status-Select	*/
#define	F_b0f1		(unsigned int)	0x0002				/* Bank0 Flash Sector 1 Status-Select	*/
#define	F_b0f2		(unsigned int)	0x0004				/* Bank0 Flash Sector 2 Status-Select	*/
#define	F_b0f3		(unsigned int)	0x0008				/* Bank0 Flash Sector 3 Status-Select	*/
#define	F_b0f4		(unsigned int)	0x0010				/* Bank0 Flash Sector 4 Status-Select	*/
#define	F_b0f5		(unsigned int)	0x0020				/* Bank0 Flash Sector 5 Status-Select	*/
#define	F_b0f6		(unsigned int)	0x0040				/* Bank0 Flash Sector 6 Status-Select	*/
#define	F_b0f7		(unsigned int)	0x0080				/* Bank0 Flash Sector 7 Status-Select	*/
#define	F_b0f8		(unsigned int)	0x0100				/* Bank0 Flash Sector 8 Status-Select	*/
#define F_b0f9		(unsigned int)	0x0200				/* Bank0 Flash Sector 9 Status-Select	*/
#define	F_b0all		(unsigned int)	0x03FF				/* Bank0 All Sectors					*/

/*	FCR1H	*/
#define	F_b3f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b1S		(unsigned int)	0x0200				/* Flash Bank1 Status	*/
#define	F_b0S		(unsigned int)	0x0100				/* Flash Bank0 Status	*/
#define	F_b1f1		(unsigned int)	0x0002				/* Bank1 Flash Sector 1 Status-Select	*/
#define	F_b1f0		(unsigned int)	0x0001				/* Bank1 Flash Sector 0 Status-Select	*/
#define	F_b1all		(unsigned int)	0x0003				/* Bank1 All Sectors					*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

#endif		/* End of F273 specific defines */
/********************************************************************/

/********************************************************************/
/*	The following define are specific to the ST10F272xxx devices	*/
#ifdef	F272

#define	Flash_Size2	1					/* Used in C file. Indicates the size of Flash as in device name */

#define MAX_IFLASH_ADDRESS	(unsigned long)0x0004FFFE
#define	MAX_FLASH_ADDRESS	(unsigned long)0x0004FFFE
#define FLASH_MAX_BANKS		0
#define	FLASH_MAX_MODULE	0
#define FLASH_MAX_SECTORS	8

#define	BANK0_START				(unsigned long)0x00010000
#define BANK0_WORDCOUNT			(unsigned long)0x00010000			// 256kByte
#define	BANK0_SECTOR0_START		(unsigned long)0x00010000
#define BANK0_SECTOR0_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR1_START		(unsigned long)0x00012000
#define BANK0_SECTOR1_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR2_START		(unsigned long)0x00014000
#define BANK0_SECTOR2_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR3_START		(unsigned long)0x00016000
#define	BANK0_SECTOR3_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR4_START		(unsigned long)0x00018000
#define BANK0_SECTOR4_WORDCOUNT	(unsigned long)0x00002000			// 32 KByte
#define	BANK0_SECTOR5_START		(unsigned long)0x00020000
#define BANK0_SECTOR5_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR6_START		(unsigned long)0x00030000
#define BANK0_SECTOR6_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR7_START		(unsigned long)0x00040000
#define BANK0_SECTOR7_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#ifdef Tasking
/* Flash control registers of the F272xx derivatives */
#define	FCR0L		*(_huge unsigned int *)(0x00080000)
#define	FCR0H		*(_huge unsigned int *)(0x00080002)
#define	FCR1L		*(_huge unsigned int *)(0x00080004)
#define	FCR1H		*(_huge unsigned int *)(0x00080006)

/* Flash data registers */
#define	FDR0L		*( _huge unsigned int *)(0x00080008)
#define	FDR0H		*( _huge unsigned int *)(0x0008000A)
#define	FDR1L		*( _huge unsigned int *)(0x0008000C)
#define	FD1RH		*( _huge unsigned int *)(0x0008000E)

#define	FDR0		*( _huge unsigned long *)(0x00080008)
#define	FDR1		*( _huge unsigned long *)(0x0008000C)

/* Flash address registers */
#define	FARL		*( _huge unsigned int *)(0x00080010)
#define	FARH		*( _huge unsigned int *)(0x00080012)

#define	FAR			*( _huge unsigned long *)(0x00080010)

/* Flash error register */
#define	FER			*( _huge unsigned int *)(0x00080014)

#elif Keil
/* Flash control registers of the F272xx derivatives */
#define	FCR0L		*( unsigned int huge *)(0x00080000)
#define	FCR0H		*( unsigned int huge *)(0x00080002)
#define	FCR1L		*( unsigned int huge *)(0x00080004)
#define	FCR1H		*( unsigned int huge *)(0x00080006)

/* Flash data registers */
#define	FDR0L		*( unsigned int huge *)(0x00080008)
#define	FDR0H		*( unsigned int huge *)(0x0008000A)
#define	FDR1L		*( unsigned int huge *)(0x0008000C)
#define	FD1RH		*( unsigned int huge *)(0x0008000E)

#define	FDR0		*( unsigned long huge *)(0x00080008)
#define	FDR1		*( unsigned long huge *)(0x0008000C)

/* Flash address registers */
#define	FARL		*( unsigned int huge *)(0x00080010)
#define	FARH		*( unsigned int huge *)(0x00080012)

#define	FAR			*( unsigned long huge *)(0x00080010)

/* Flash error register */
#define	FER			*( unsigned int huge *)(0x00080014)

#endif		// Tasking - Keil selection

/*	FCR0L	*/
#define	F_lock			0x0010             /* Flash register access locked */
#define	F_bsy0			0x0002             /* Bank 0 busy    */

/*	FCR0H	*/
#define F_spr		(unsigned int)	0x0100				/* Set protection		*/
#define	F_ser		(unsigned int)	0x0800				/* Sector Erase			*/
#define	F_dwpg		(unsigned int)	0x1000				/* Double Word Program	*/
#define	F_wpg		(unsigned int)	0x2000				/* Word Program			*/
#define F_susp		(unsigned int)	0x4000				/* Suspend				*/
#define	F_wms		(unsigned int)	0x8000				/* Write Mode Start		*/

/*	FCR1L	*/
#define	F_b2f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f2		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0f0		(unsigned int)	0x0001				/* Bank0 Flash Sector 0 Status-Select	*/
#define	F_b0f1		(unsigned int)	0x0002				/* Bank0 Flash Sector 1 Status-Select	*/
#define	F_b0f2		(unsigned int)	0x0004				/* Bank0 Flash Sector 2 Status-Select	*/
#define	F_b0f3		(unsigned int)	0x0008				/* Bank0 Flash Sector 3 Status-Select	*/
#define	F_b0f4		(unsigned int)	0x0010				/* Bank0 Flash Sector 4 Status-Select	*/
#define	F_b0f5		(unsigned int)	0x0020				/* Bank0 Flash Sector 5 Status-Select	*/
#define	F_b0f6		(unsigned int)	0x0040				/* Bank0 Flash Sector 6 Status-Select	*/
#define	F_b0f7		(unsigned int)	0x0080				/* Bank0 Flash Sector 7 Status-Select	*/
#define	F_b0f8		(unsigned int)	0x0000				/* 0 so no action					*/
#define F_b0f9		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b0all		(unsigned int)	0x00FF				/* Bank0 All Sectors					*/

/*	FCR1H	*/
#define	F_b3f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0S		(unsigned int)	0x0100				/* Flash Bank0 Status	*/
#define	F_b1f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b1f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b1all		(unsigned int)	0x0000				/* 0 so no action					*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

#endif		/* End of F272 specific defines */
/********************************************************************/

/********************************************************************/
/*	The following define are specific to the ST10F271xxx devices	*/
#ifdef	F271
/*****************************************/
/*	The following define are specific	*/
/* to the ST10F271xx devices			*/
/*****************************************/

#define	Flash_Size1	1					/* Used in C file. Indicates the size of Flash as in device name */

#define MAX_IFLASH_ADDRESS	(unsigned long)0x0002FFFE
#define	MAX_FLASH_ADDRESS	(unsigned long)0x0002FFFE
#define FLASH_MAX_BANKS		0
#define	FLASH_MAX_MODULE	0
#define FLASH_MAX_SECTORS	6

#define	BANK0_START				(unsigned long)0x00010000
#define BANK0_WORDCOUNT			(unsigned long)0x00008000			// 128kByte
#define	BANK0_SECTOR0_START		(unsigned long)0x00010000
#define BANK0_SECTOR0_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR1_START		(unsigned long)0x00012000
#define BANK0_SECTOR1_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR2_START		(unsigned long)0x00014000
#define BANK0_SECTOR2_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR3_START		(unsigned long)0x00016000
#define	BANK0_SECTOR3_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR4_START		(unsigned long)0x00018000
#define BANK0_SECTOR4_WORDCOUNT	(unsigned long)0x00002000			// 32 KByte
#define	BANK0_SECTOR5_START		(unsigned long)0x00020000
#define BANK0_SECTOR5_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#ifdef Tasking
/* Flash control registers of the F271xx derivatives */
#define	FCR0L		*(_huge unsigned int *)(0x00080000)
#define	FCR0H		*(_huge unsigned int *)(0x00080002)
#define	FCR1L		*(_huge unsigned int *)(0x00080004)
#define	FCR1H		*(_huge unsigned int *)(0x00080006)

/* Flash data registers */
#define	FDR0L		*( _huge unsigned int *)(0x00080008)
#define	FDR0H		*( _huge unsigned int *)(0x0008000A)
#define	FDR1L		*( _huge unsigned int *)(0x0008000C)
#define	FD1RH		*( _huge unsigned int *)(0x0008000E)

#define	FDR0		*( _huge unsigned long *)(0x00080008)
#define	FDR1		*( _huge unsigned long *)(0x0008000C)

/* Flash address registers */
#define	FARL		*( _huge unsigned int *)(0x00080010)
#define	FARH		*( _huge unsigned int *)(0x00080012)

#define	FAR			*( _huge unsigned long *)(0x00080010)

/* Flash error register */
#define	FER			*( _huge unsigned int *)(0x00080014)

#elif Keil
/* Flash control registers of the F271xx derivatives */
#define	FCR0L		*( unsigned int huge *)(0x00080000)
#define	FCR0H		*( unsigned int huge *)(0x00080002)
#define	FCR1L		*( unsigned int huge *)(0x00080004)
#define	FCR1H		*( unsigned int huge *)(0x00080006)

/* Flash data registers */
#define	FDR0L		*( unsigned int huge *)(0x00080008)
#define	FDR0H		*( unsigned int huge *)(0x0008000A)
#define	FDR1L		*( unsigned int huge *)(0x0008000C)
#define	FD1RH		*( unsigned int huge *)(0x0008000E)

#define	FDR0		*( unsigned long huge *)(0x00080008)
#define	FDR1		*( unsigned long huge *)(0x0008000C)

/* Flash address registers */
#define	FARL		*( unsigned int huge *)(0x00080010)
#define	FARH		*( unsigned int huge *)(0x00080012)

#define	FAR			*( unsigned long huge *)(0x00080010)

/* Flash error register */
#define	FER			*( unsigned int huge *)(0x00080014)

#endif		// Tasking - Keil selection

/*	FCR0L	*/
#define	F_lock			0x0010             /* Flash register access locked */
#define	F_bsy0			0x0002             /* Bank 0 busy    */

/*	FCR0H	*/
#define F_spr		(unsigned int)	0x0100				/* Set protection		*/
#define	F_ser		(unsigned int)	0x0800				/* Sector Erase			*/
#define	F_dwpg		(unsigned int)	0x1000				/* Double Word Program	*/
#define	F_wpg		(unsigned int)	0x2000				/* Word Program			*/
#define F_susp		(unsigned int)	0x4000				/* Suspend				*/
#define	F_wms		(unsigned int)	0x8000				/* Write Mode Start		*/

/*	FCR1L	*/
#define	F_b2f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f2		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0f0		(unsigned int)	0x0001				/* Bank0 Flash Sector 0 Status-Select	*/
#define	F_b0f1		(unsigned int)	0x0002				/* Bank0 Flash Sector 1 Status-Select	*/
#define	F_b0f2		(unsigned int)	0x0004				/* Bank0 Flash Sector 2 Status-Select	*/
#define	F_b0f3		(unsigned int)	0x0008				/* Bank0 Flash Sector 3 Status-Select	*/
#define	F_b0f4		(unsigned int)	0x0010				/* Bank0 Flash Sector 4 Status-Select	*/
#define	F_b0f5		(unsigned int)	0x0020				/* Bank0 Flash Sector 5 Status-Select	*/
#define	F_b0f6		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b0f7		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b0f8		(unsigned int)	0x0000				/* 0 so no action					*/
#define F_b0f9		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b0all		(unsigned int)	0x003F				/* Bank0 All Sectors					*/

/*	FCR1H	*/
#define	F_b3f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0S		(unsigned int)	0x0100				/* Flash Bank0 Status	*/
#define	F_b1f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b1f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b1all		(unsigned int)	0x0000				/* 0 so no action					*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

#endif		/* End of F271 specific defines */


/********************************************************************/
/*	The following define are specific to the ST10F252xxx devices	*/
#ifdef	F252

#define	Flash_Size2	1					/* Used in C file. Indicates the size of Flash as in device name */

#define MAX_IFLASH_ADDRESS	(unsigned long)0x0004FFFE
#define	MAX_FLASH_ADDRESS	(unsigned long)0x0004FFFE
#define FLASH_MAX_BANKS		0
#define	FLASH_MAX_MODULE	0
#define FLASH_MAX_SECTORS	8

#define	BANK0_START				(unsigned long)0x00010000
#define BANK0_WORDCOUNT			(unsigned long)0x00010000			// 256kByte
#define	BANK0_SECTOR0_START		(unsigned long)0x00010000
#define BANK0_SECTOR0_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR1_START		(unsigned long)0x00012000
#define BANK0_SECTOR1_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR2_START		(unsigned long)0x00014000
#define BANK0_SECTOR2_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR3_START		(unsigned long)0x00016000
#define	BANK0_SECTOR3_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR4_START		(unsigned long)0x00018000
#define BANK0_SECTOR4_WORDCOUNT	(unsigned long)0x00002000			// 32 KByte
#define	BANK0_SECTOR5_START		(unsigned long)0x00020000
#define BANK0_SECTOR5_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR6_START		(unsigned long)0x00030000
#define BANK0_SECTOR6_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte
#define	BANK0_SECTOR7_START		(unsigned long)0x00040000
#define BANK0_SECTOR7_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#ifdef Tasking
/* Flash control registers of the F252xx derivatives */
#define	FCR0L		*(_huge unsigned int *)(0x00080000)
#define	FCR0H		*(_huge unsigned int *)(0x00080002)
#define	FCR1L		*(_huge unsigned int *)(0x00080004)
#define	FCR1H		*(_huge unsigned int *)(0x00080006)

/* Flash data registers */
#define	FDR0L		*( _huge unsigned int *)(0x00080008)
#define	FDR0H		*( _huge unsigned int *)(0x0008000A)
#define	FDR1L		*( _huge unsigned int *)(0x0008000C)
#define	FD1RH		*( _huge unsigned int *)(0x0008000E)

#define	FDR0		*( _huge unsigned long *)(0x00080008)
#define	FDR1		*( _huge unsigned long *)(0x0008000C)

/* Flash address registers */
#define	FARL		*( _huge unsigned int *)(0x00080010)
#define	FARH		*( _huge unsigned int *)(0x00080012)

#define	FAR			*( _huge unsigned long *)(0x00080010)

/* Flash error register */
#define	FER			*( _huge unsigned int *)(0x00080014)

#elif Keil
/* Flash control registers of the F252xx derivatives */
#define	FCR0L		*( unsigned int huge *)(0x00080000)
#define	FCR0H		*( unsigned int huge *)(0x00080002)
#define	FCR1L		*( unsigned int huge *)(0x00080004)
#define	FCR1H		*( unsigned int huge *)(0x00080006)

/* Flash data registers */
#define	FDR0L		*( unsigned int huge *)(0x00080008)
#define	FDR0H		*( unsigned int huge *)(0x0008000A)
#define	FDR1L		*( unsigned int huge *)(0x0008000C)
#define	FD1RH		*( unsigned int huge *)(0x0008000E)

#define	FDR0		*( unsigned long huge *)(0x00080008)
#define	FDR1		*( unsigned long huge *)(0x0008000C)

/* Flash address registers */
#define	FARL		*( unsigned int huge *)(0x00080010)
#define	FARH		*( unsigned int huge *)(0x00080012)

#define	FAR			*( unsigned long huge *)(0x00080010)

/* Flash error register */
#define	FER			*( unsigned int huge *)(0x00080014)

#endif		// Tasking - Keil selection

/*	FCR0L	*/
#define	F_lock			0x0010             /* Flash register access locked */
#define	F_bsy0			0x0002             /* Bank 0 busy    */

/*	FCR0H	*/
#define F_spr		(unsigned int)	0x0100				/* Set protection		*/
#define	F_ser		(unsigned int)	0x0800				/* Sector Erase			*/
#define	F_dwpg		(unsigned int)	0x1000				/* Double Word Program	*/
#define	F_wpg		(unsigned int)	0x2000				/* Word Program			*/
#define F_susp		(unsigned int)	0x4000				/* Suspend				*/
#define	F_wms		(unsigned int)	0x8000				/* Write Mode Start		*/

/*	FCR1L	*/
#define	F_b2f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f2		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0f0		(unsigned int)	0x0001				/* Bank0 Flash Sector 0 Status-Select	*/
#define	F_b0f1		(unsigned int)	0x0002				/* Bank0 Flash Sector 1 Status-Select	*/
#define	F_b0f2		(unsigned int)	0x0004				/* Bank0 Flash Sector 2 Status-Select	*/
#define	F_b0f3		(unsigned int)	0x0008				/* Bank0 Flash Sector 3 Status-Select	*/
#define	F_b0f4		(unsigned int)	0x0010				/* Bank0 Flash Sector 4 Status-Select	*/
#define	F_b0f5		(unsigned int)	0x0020				/* Bank0 Flash Sector 5 Status-Select	*/
#define	F_b0f6		(unsigned int)	0x0040				/* Bank0 Flash Sector 6 Status-Select	*/
#define	F_b0f7		(unsigned int)	0x0080				/* Bank0 Flash Sector 7 Status-Select	*/
#define	F_b0f8		(unsigned int)	0x0000				/* 0 so no action					*/
#define F_b0f9		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b0all		(unsigned int)	0x00FF				/* Bank0 All Sectors					*/

/*	FCR1H	*/
#define	F_b3f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0S		(unsigned int)	0x0100				/* Flash Bank0 Status	*/
#define	F_b1f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b1f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b1all		(unsigned int)	0x0000				/* 0 so no action					*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

#endif		/* End of F252 specific defines */
/********************************************************************/

/********************************************************************/
/*	The following define are specific to the ST10F251xxx devices	*/
#ifdef	F251
/*****************************************/
/*	The following define are specific	*/
/* to the ST10F251xx devices			*/
/*****************************************/

#define	Flash_Size1	1					/* Used in C file. Indicates the size of Flash as in device name */

#define MAX_IFLASH_ADDRESS	(unsigned long)0x0002FFFE
#define	MAX_FLASH_ADDRESS	(unsigned long)0x0002FFFE
#define FLASH_MAX_BANKS		0
#define	FLASH_MAX_MODULE	0
#define FLASH_MAX_SECTORS	6

#define	BANK0_START				(unsigned long)0x00010000
#define BANK0_WORDCOUNT			(unsigned long)0x00008000			// 128kByte
#define	BANK0_SECTOR0_START		(unsigned long)0x00010000
#define BANK0_SECTOR0_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR1_START		(unsigned long)0x00012000
#define BANK0_SECTOR1_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR2_START		(unsigned long)0x00014000
#define BANK0_SECTOR2_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR3_START		(unsigned long)0x00016000
#define	BANK0_SECTOR3_WORDCOUNT	(unsigned long)0x00000800			// 8 KByte
#define	BANK0_SECTOR4_START		(unsigned long)0x00018000
#define BANK0_SECTOR4_WORDCOUNT	(unsigned long)0x00002000			// 32 KByte
#define	BANK0_SECTOR5_START		(unsigned long)0x00020000
#define BANK0_SECTOR5_WORDCOUNT	(unsigned long)0x00004000			// 64 KByte

#ifdef Tasking
/* Flash control registers of the F251xx derivatives */
#define	FCR0L		*(_huge unsigned int *)(0x00080000)
#define	FCR0H		*(_huge unsigned int *)(0x00080002)
#define	FCR1L		*(_huge unsigned int *)(0x00080004)
#define	FCR1H		*(_huge unsigned int *)(0x00080006)

/* Flash data registers */
#define	FDR0L		*( _huge unsigned int *)(0x00080008)
#define	FDR0H		*( _huge unsigned int *)(0x0008000A)
#define	FDR1L		*( _huge unsigned int *)(0x0008000C)
#define	FD1RH		*( _huge unsigned int *)(0x0008000E)

#define	FDR0		*( _huge unsigned long *)(0x00080008)
#define	FDR1		*( _huge unsigned long *)(0x0008000C)

/* Flash address registers */
#define	FARL		*( _huge unsigned int *)(0x00080010)
#define	FARH		*( _huge unsigned int *)(0x00080012)

#define	FAR			*( _huge unsigned long *)(0x00080010)

/* Flash error register */
#define	FER			*( _huge unsigned int *)(0x00080014)

#elif Keil
/* Flash control registers of the F251xx derivatives */
#define	FCR0L		*( unsigned int huge *)(0x00080000)
#define	FCR0H		*( unsigned int huge *)(0x00080002)
#define	FCR1L		*( unsigned int huge *)(0x00080004)
#define	FCR1H		*( unsigned int huge *)(0x00080006)

/* Flash data registers */
#define	FDR0L		*( unsigned int huge *)(0x00080008)
#define	FDR0H		*( unsigned int huge *)(0x0008000A)
#define	FDR1L		*( unsigned int huge *)(0x0008000C)
#define	FD1RH		*( unsigned int huge *)(0x0008000E)

#define	FDR0		*( unsigned long huge *)(0x00080008)
#define	FDR1		*( unsigned long huge *)(0x0008000C)

/* Flash address registers */
#define	FARL		*( unsigned int huge *)(0x00080010)
#define	FARH		*( unsigned int huge *)(0x00080012)

#define	FAR			*( unsigned long huge *)(0x00080010)

/* Flash error register */
#define	FER			*( unsigned int huge *)(0x00080014)

#endif		// Tasking - Keil selection

/*	FCR0L	*/
#define	F_lock			0x0010             /* Flash register access locked */
#define	F_bsy0			0x0002             /* Bank 0 busy    */

/*	FCR0H	*/
#define F_spr		(unsigned int)	0x0100				/* Set protection		*/
#define	F_ser		(unsigned int)	0x0800				/* Sector Erase			*/
#define	F_dwpg		(unsigned int)	0x1000				/* Double Word Program	*/
#define	F_wpg		(unsigned int)	0x2000				/* Word Program			*/
#define F_susp		(unsigned int)	0x4000				/* Suspend				*/
#define	F_wms		(unsigned int)	0x8000				/* Write Mode Start		*/

/*	FCR1L	*/
#define	F_b2f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2f2		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b2all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0f0		(unsigned int)	0x0001				/* Bank0 Flash Sector 0 Status-Select	*/
#define	F_b0f1		(unsigned int)	0x0002				/* Bank0 Flash Sector 1 Status-Select	*/
#define	F_b0f2		(unsigned int)	0x0004				/* Bank0 Flash Sector 2 Status-Select	*/
#define	F_b0f3		(unsigned int)	0x0008				/* Bank0 Flash Sector 3 Status-Select	*/
#define	F_b0f4		(unsigned int)	0x0010				/* Bank0 Flash Sector 4 Status-Select	*/
#define	F_b0f5		(unsigned int)	0x0020				/* Bank0 Flash Sector 5 Status-Select	*/
#define	F_b0f6		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b0f7		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b0f8		(unsigned int)	0x0000				/* 0 so no action					*/
#define F_b0f9		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b0all		(unsigned int)	0x003F				/* Bank0 All Sectors					*/

/*	FCR1H	*/
#define	F_b3f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b3all		(unsigned int)	0x0000				/* 0 so no action					*/

#define	F_b0S		(unsigned int)	0x0100				/* Flash Bank0 Status	*/
#define	F_b1f1		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b1f0		(unsigned int)	0x0000				/* 0 so no action					*/
#define	F_b1all		(unsigned int)	0x0000				/* 0 so no action					*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

/* Bits of the FER register */
#define	F_wpf		(unsigned int)	0x0100			/* Write Protection Flag*/
#define	F_reser		(unsigned int)	0x0080			/* Resume Error			*/
#define	F_seqer		(unsigned int)	0x0040			/* Sequence Error		*/
#define	F_10er		(unsigned int)	0x0008			/* 1 over 0 Error		*/
#define	F_pger		(unsigned int)	0x0004			/* Program Error		*/
#define	F_erer		(unsigned int)	0x0002			/* Erase Error			*/
#define	F_err		(unsigned int)	0x0001			/* Write Error			*/

#endif		/* End of F251 specific defines */




#endif

