/****************************************************************************
*																			*
* HEADER_START                                                        		*
*                                                                     		*
*		Name:           ST10 Flash drivers for the 0.18um devices      		*
*		Project:                                                       		*
*		Description:    Definition of the Flash control registers      		*
*		Processor:      ST10F27x, F29x, F25x                            	*
*		HW:                                                            		*
*		Revision:       1.4                                           		*
*		Date:           May, 2004                                      		*
*		Compiler:       C crosscompiler Tasking V8.0r2                 		*
*						C crosscompiler Keil uVision2 v2.36					*
*																			*
*		Author:         C. A.                                      			*
*		Company:        ST Microelectronics                            		*
*		                France												*
*		Security:       													*
*																			*
*		Contact:		st10.support@st.com									*
*						http://www.stmcu.com                           		*
* ========================================================================= *
* Copyright (c):      ST Microelectronics.,2004, All rights reserved. 		*
*                                                                     		*
* =========================================================================== *
*
* HEADER_END
*/

#include "F27x_flash.h"
#include "flash.h"

#ifdef Tasking
#include <reg276.h>

#elif Keil
#include <ST10F276.h>
#endif


/************************/
/*	ERASE FUNCTIONS		*/
/************************/

/****************************************/
/* Erase the specified Flash Bank		*/
/****************************************/
void FlashBankErase( int Bank )
{
    if ( Bank == 0 )							/* I-Flash for Bank 0 & 1 */
    {
        FlashMultiSectorErase( Bank, F_b0all );
    }
#ifndef	Flash_Size1
#ifndef	Flash_Size2
    else if ( Bank == 1 )							/* I-Flash for Bank 0 & 1 */
    {
        FlashMultiSectorErase( Bank, F_b1all );
    }
#ifndef	Flash_Size3
    else if ( Bank == 2 )							/* X-Flash for Bank 2 & 3 */
    {
        FlashMultiSectorErase( Bank, F_b2all );
    }
#ifndef	Flash_Size5
    else if ( Bank == 3 )							/* X-Flash for Bank 2 & 3 */
    {
        FlashMultiSectorErase( Bank, F_b3all );
    }
#endif		// Flash_Size5
#endif		// Flash_Size3
#endif		// Flash_Size2
#endif		// Flash_Size1

    /* Returns without waiting for completion. The module erase time is 5.1s typical!	*/
    /* User can implement their own function using the FlashWait function.				*/
}

/******************************************************************************/
// Erase the specified Flash Sector (Bank, Block)
// This currently works on 1 Sector per call
/******************************************************************************/
void FlashSectorErase( int Bank, int Block )
{
    switch ( Bank )
    {
    case 0:
#ifndef Flash_Size2
#ifndef Flash_Size1
        FCR0H = FCR0H | F_Ismod;					// Set the Select Module bit to work on the XFlash
#endif
#endif
        FCR0H = FCR0H | F_ser;						// Set the Sector Erase Bit
        FCR1L = FCR1L | (F_b0f0 << Block);    		// Set the specified Bank Status Bit
        FCR0H = FCR0H | F_wms; break;				// Set the Write Mode Start Bit
#ifndef Flash_Size2
#ifndef Flash_Size1
    case 1:
        FCR0H = FCR0H | F_Ismod;					// Set the Select Module bit to work on the XFlash
        FCR0H = FCR0H | F_ser;						// Set the Sector Erase Bit
        FCR1H = FCR1H | (F_b1f0 << Block);			// Set the specified Bank Status Bit
        FCR0H = FCR0H | F_wms; break;				// Set the Write Mode Start Bit
#ifndef Flash_Size3
    case 2:
        FCR0H = FCR0H & F_Xsmod;					// Clear the Select Module bit to work on the XFlash
        FCR0H = FCR0H | F_ser;						// Set the Sector Erase Bit
        FCR1L = FCR1L | (F_b2f0 << Block);			// Set the specified Bank Status Bit
        FCR0H = FCR0H | F_wms; break;				// Set the Write Mode Start Bit
#ifndef Flash_Size5
    case 3:
        FCR0H = FCR0H & F_Xsmod;					// Clear the Select Module bit to work on the XFlash
        FCR0H = FCR0H | F_ser;						// Set the Sector Erase Bit
        FCR1H = FCR1H | (F_b3f0 << Block);			// Set the specified Bank Status Bit
        FCR0H = FCR0H | F_wms; break;				// Set the Write Mode Start Bit
#endif			//Flash_Size1
#endif			//Flash_Size2
#endif			//Flash_Size3
#endif			//Flash_Size5
    default:
        break;
    }

    //	WAIT_FOR_UNLOCK
    /* Returns without waiting for completion. The module erase time is 5.1s typical!	*/
    /* User can imlement their own function using the FlashWait function.				*/
}


/******************************************************************************/
//	Erase the specified Flash Sectors of a Bank
// The Sectors or specified by Blocks parameter that is a mask
// of the sectors number to erase.
/******************************************************************************/
void FlashMultiSectorErase( int Bank, int Blocks )
{
    int Mask;

    switch ( Bank )
    {
    case 0:
#ifndef Flash_Size2
#ifndef Flash_Size1
        FCR0H = FCR0H | F_Ismod;			// Set the Select Module bit to work on the IFlash
#endif
#endif
        FCR0H = FCR0H | F_ser;				// Set the Sector Erase Bit
        Mask = Blocks & F_b0all;
        FCR1L = FCR1L | Mask;					    // Set the specified Bank Status Bit
        break;
#ifndef Flash_Size2
#ifndef Flash_Size1
    case 1:
        FCR0H = FCR0H | F_Ismod;			// Set the Select Module bit to work on the IFlash
        FCR0H = FCR0H | F_ser;				// Set the Sector Erase Bit
        Mask = Blocks & F_b1all;
        FCR1H = FCR1H | Mask;				// Set the specified Bank Status Bit
        break;
#ifndef Flash_Size3
    case 2:
        FCR0H = FCR0H & F_Xsmod;			// Clear the Select Module bit to work on the XFlash
        FCR0H = FCR0H | F_ser;				// Set the Sector Erase Bit
        Mask = Blocks & F_b2all;
        FCR1L = FCR1L | Mask;				// Set the specified Bank Status Bit
        break;
#ifndef Flash_Size5
    case 3:
        FCR0H = FCR0H & F_Xsmod;			// Clear the Select Module bit to work on the XFlash
        FCR0H = FCR0H | F_ser;				// Set the Sector Erase Bit
        Mask = Blocks & F_b3all;
        FCR1H = FCR1H | Mask;				// Set the specified Bank Status Bit
        break;
#endif				//Flash_Size5
#endif				//Flash_Size3
#endif				//Flash_Size2
#endif				//Flash_Size1
    default:
        break;
    }

    FCR0H = FCR0H | F_wms;						// Set the Write Mode Start Bit

    /* Returns without waiting for completion. The module erase time is 5.1s typical!	*/
    /* User can imlement their own function using the FlashWait function.				*/
}


/********************************/
/*	PROGRAMMING FUNCTIONS		*/
/********************************/

/************************************************************/
/*	Program a single Word to the specified Flash Address	*/
/************************************************************/
unsigned int FlashProgramWord(unsigned long Address, unsigned long Data)
{
#ifdef Flash_Size1
    if ( Address > MAX_IFLASH_ADDRESS)
        return( FLASH_INVALID_ADDRESS);
#elif Flash_Size2
    if ( Address > MAX_IFLASH_ADDRESS)
        return( FLASH_INVALID_ADDRESS);
#endif

#ifndef Flash_Size1
#ifndef Flash_Size2
    if ( Address <= MAX_IFLASH_ADDRESS)
        FCR0H = FCR0H | F_Ismod;			// Set the Select Module bit to work on the IFlash
#ifndef Flash_Size3
    else if ( Address <= MAX_XFLASH_ADDRESS )
        FCR0H = FCR0H & F_Xsmod;			// Clear the Select Module bit to work on the XFlash
#endif		// Flash_Size3
    else
        return( FLASH_INVALID_ADDRESS);
#endif
#endif
    if ( (0x0000 <= Address) & (Address <0x08000))
    {
        Address = Address | 0x00010000;		// When programming we must have the address in segment 1
    }
    FCR0H = FCR0H | F_wpg;					// Set the Word Programming Bit
    FAR  =  Address;				// Load the Address
    FDR0 =  Data;					// Load the Data
    FCR0H = FCR0H | F_wms;					// Set the Write Mode Start Bit

    return( FlashWait(FLASH_DELAY_400USEC) );		// Wait for the operation to complete
}

/************************************************************/
/*	Program a double Word to the specified Flash Address	*/
/************************************************************/
unsigned int FlashProgramDoubleWord( unsigned long Address, unsigned long Data1, unsigned long Data2 )
{
#ifdef Flash_Size1
    if ( Address > MAX_IFLASH_ADDRESS)
        return( FLASH_INVALID_ADDRESS);
#endif
#ifdef Flash_Size2
    if ( Address > MAX_IFLASH_ADDRESS)
        return( FLASH_INVALID_ADDRESS);
#endif

#ifndef Flash_Size1
#ifndef Flash_Size2
    if ( Address <= MAX_IFLASH_ADDRESS)
        FCR0H = FCR0H | F_Ismod;			// Set the Select Module bit to work on the IFlash
#ifndef Flash_Size3
    else if ( Address <= MAX_XFLASH_ADDRESS )
        FCR0H = FCR0H & F_Xsmod;			// Clear the Select Module bit to work on the XFlash
#endif		// Flash_Size3
    else
        return( FLASH_INVALID_ADDRESS);
#endif
#endif

    FCR0H = FCR0H | F_dwpg;				// Set the Double Word Programming Bit
    FAR  =  Address;				// Load the Address
    FDR0 =  Data1;					// Load the first word
    FDR1 =  Data2;					// Load the second word
    FCR0H = FCR0H | F_wms;					// Set the Write Mode Start Bit

    return( FlashWait(FLASH_DELAY_800USEC) );		// Wait for the operation to complete
}

/*********************************/
/*	Program a Range of Flash	*/
/********************************/
unsigned int FlashProgramRange( unsigned long Destination, unsigned long Source, unsigned long WordCount )
{
    unsigned int Status = 0;

    while ( WordCount-- )
    {
#ifdef Keil
        Status = FlashProgramWord( Destination, *(unsigned long huge *)Source );
#else
#ifdef  Tasking
        Status = FlashProgramWord( Destination, *(_huge unsigned long *)Source );
#endif
#endif
        // If an ERROR occurred, Then return the ERROR code
        if ( Status != FLASH_OPERATION_COMPLETE ) return( Status );

        Destination	= Destination + 4;				// 32bit Word increment
        Source		= Source + 4;					// 32bit Word increment
    }
    return( Status );
}

/********************************/
/*	Program a Range of Flash	*/
/* with the specified Pattern	*/
/********************************/
unsigned int FlashProgramPattern( unsigned long Destination, unsigned long WordCount, unsigned long Pattern )
{
    unsigned int Status = 0;

    while ( WordCount-- )
    {
        Status = FlashProgramWord( Destination, Pattern );

        // If an ERROR occurred, Then return the ERROR code
        if ( Status != FLASH_OPERATION_COMPLETE ) return( Status );

        Destination = Destination + 4;					// 32bit Word increment
    }
    return( Status );
}

/********************************/
/*	VERIFY FUNCTIONS			*/
/********************************/
unsigned int FlashVerifyWord( unsigned long Address, unsigned long Data)
{
    unsigned long FlashData;
    unsigned int VerifyStatus = 0;

    if ( SYSCON & 0x1000 )				// Check where the first 32K of IFlash are mapped
    {									// The Flash is mapped from Segment 1
        if ( Address < 0x8000 )			// all the addresses must begin after 01'0000h
            Address = Address | 0x00010000;
    }
    else
    {									// The first 32K are in Segment 0
        if ( (0x00010000 <= Address) & ( Address < 0x00018000) )
            Address = Address & 0xFFFEFFFF;		// Forces the first 32K from 00'0000h to 00'7FFFh
    }

#ifdef Keil
    FlashData = *(unsigned long huge *)Address;
//#elif Tasking


#else
#ifdef Tasking
    FlashData = *( _huge unsigned long *)Address;
#endif
#endif
    if ( FlashData != Data )
        VerifyStatus = VERIFY_ERROR;

    return( VerifyStatus );
}

unsigned int FlashVerifyDoubleWord( unsigned long Address, unsigned long Data1, unsigned long Data2)
{
    unsigned long FlashData;
    unsigned int VerifyStatus = 0;

    if ( SYSCON & 0x1000 )				// Check where the first 32K of IFlash are mapped
    {									// The Flash is mapped from Segment 1
        if ( Address < 0x8000 )			// all the addresses must begin after 01'0000h
            Address = Address | (long)0x00010000;
    }
    else
    {									// The first 32K are in Segment 0
        if ( (0x00010000 <= Address) & (Address < 0x00018000) )
            Address = Address & (long)0xFFFEFFFF;		// Forces the first 32K from 00'0000h to 00'7FFFh
    }

#ifdef Keil
    FlashData = *(unsigned long huge *)Address;
#else
#ifdef   Tasking
    FlashData = *( _huge unsigned long *)Address;
#endif
#endif

    if ( FlashData != Data1 )
        VerifyStatus = VERIFY_ERROR;
    else
    {
        Address = Address + 4;						// 32bit Word increment
#ifdef Keil
        FlashData = *(unsigned long huge *)Address;
#else
#ifdef Tasking
        FlashData = *( _huge unsigned long *)Address;
#endif
#endif
        if ( FlashData != Data2)
            VerifyStatus = VERIFY_ERROR;
    }

    return( VerifyStatus );
}


unsigned long FlashVerifyRange( unsigned long Source, unsigned long Destination, unsigned long WordCount)
{
    unsigned int VerifyStatus;
    unsigned long Tempo;
    while ( WordCount-- )
    {
#ifdef Keil
        Tempo = *(unsigned long huge *)Source;
#else
#ifdef Tasking
        Tempo = *( _huge unsigned long *)Source;
#endif
#endif

        VerifyStatus = FlashVerifyWord( Destination, Tempo );
        if ( VerifyStatus )
            return( Destination );				// If not equal, Then return the Address

        Destination	= Destination + 4;			// 32bit Word increment
        Source		= Source + 4;				// 32bit Word increment
    }

    return( VerifyStatus = 1 );
}

unsigned long FlashVerifyPattern( unsigned long Destination, unsigned long WordCount, unsigned long Pattern )
{
    unsigned int VerifyStatus;
    while ( WordCount-- )
    {
        VerifyStatus = FlashVerifyWord( Destination, Pattern );
        if ( VerifyStatus )
            return( Destination );				// If not equal, Then return the Address

        Destination = Destination + 4;			// 32bit Word increment
    }

    return( VerifyStatus = 1 );
}

/********************************/
/*	BLANK CHECK FUNCTIONS		*/
/********************************/

unsigned long FlashBankBlankCheck( int Bank )
{
    unsigned long Address;
    unsigned long WordCount;
    unsigned long VerifyStatus = 1;

    switch ( Bank )
    {
    case 0:
        Address = BANK0_START;
        WordCount = BANK0_WORDCOUNT;
        break;
#ifndef Flash_Size2
#ifndef Flash_Size1
    case 1:
        Address = BANK1_START;
        WordCount = BANK1_WORDCOUNT;
        break;
#ifndef Flash_Size3
    case 2:
        Address = BANK2_START;
        WordCount = BANK2_WORDCOUNT;
        break;
#ifndef Flash_Size5
    case 3:
        Address = BANK3_START;
        WordCount = BANK3_WORDCOUNT;
        break;
#endif
#endif
#endif
#endif
    default :
        return( FLASH_INVALID_BANK );
    }


    while ( WordCount-- )
    {
        VerifyStatus = FlashVerifyWord( Address, BLANK_WORD );
        if ( VerifyStatus )
            return( Address );			// Return Address (!= 1) of first not blank location
        else
            Address = Address + 4;				// 32bit Word increment
    }
    return( VerifyStatus = 1 );					// Return 1 if all blank
}

unsigned long FlashSectorBlankCheck( int Bank, int Sector )
{
    unsigned long Address = 0;
    unsigned long WordCount = 0;
    unsigned long VerifyStatus = 1;

    if ( Bank > FLASH_MAX_BANKS )
        return( FLASH_INVALID_BANK );
    else if ( Bank == 0 )
    {
        switch ( Sector )
        {
        case 0:
            Address = BANK0_SECTOR0_START; WordCount = BANK0_SECTOR0_WORDCOUNT; break;
        case 1:
            Address = BANK0_SECTOR1_START; WordCount = BANK0_SECTOR1_WORDCOUNT; break;
        case 2:
            Address = BANK0_SECTOR2_START; WordCount = BANK0_SECTOR2_WORDCOUNT; break;
        case 3:
            Address = BANK0_SECTOR3_START; WordCount = BANK0_SECTOR3_WORDCOUNT; break;
        case 4:
            Address = BANK0_SECTOR4_START; WordCount = BANK0_SECTOR4_WORDCOUNT; break;
        case 5:
            Address = BANK0_SECTOR5_START; WordCount = BANK0_SECTOR5_WORDCOUNT; break;
#ifndef Flash_Size1
        case 6:
            Address = BANK0_SECTOR6_START; WordCount = BANK0_SECTOR6_WORDCOUNT; break;
        case 7:
            Address = BANK0_SECTOR7_START; WordCount = BANK0_SECTOR7_WORDCOUNT; break;
#ifndef Flash_Size2
        case 8:
            Address = BANK0_SECTOR8_START; WordCount = BANK0_SECTOR8_WORDCOUNT; break;
        case 9:
            Address = BANK0_SECTOR9_START; WordCount = BANK0_SECTOR9_WORDCOUNT; break;
#endif
#endif
        default :
            return( FLASH_INVALID_SECTOR );
        }
    }
#ifndef Flash_Size1
#ifndef Flash_Size2
    else if ( Bank == 1 )
    {
        switch ( Sector )
        {
        case 0:
            Address = BANK1_SECTOR0_START; WordCount = BANK1_SECTOR0_WORDCOUNT; break;
        case 1:
            Address = BANK1_SECTOR1_START; WordCount = BANK1_SECTOR1_WORDCOUNT; break;
        default :
            return( FLASH_INVALID_SECTOR );
        }
    }
#ifndef Flash_Size3
    else if ( Bank == 2 )
    {
        switch ( Sector )
        {
        case 0:
            Address = BANK2_SECTOR0_START; WordCount = BANK2_SECTOR0_WORDCOUNT; break;
        case 1:
            Address = BANK2_SECTOR1_START; WordCount = BANK2_SECTOR1_WORDCOUNT; break;
        case 2:
            Address = BANK2_SECTOR2_START; WordCount = BANK2_SECTOR2_WORDCOUNT; break;
        default :
            return( FLASH_INVALID_SECTOR );
        }
    }
#ifndef Flash_Size5
    else if ( Bank == 3 )
    {
        switch ( Sector )
        {
        case 0:
            Address = BANK3_SECTOR0_START; WordCount = BANK3_SECTOR0_WORDCOUNT; break;
        case 1:
            Address = BANK3_SECTOR1_START; WordCount = BANK3_SECTOR1_WORDCOUNT; break;
        default :
            return( FLASH_INVALID_SECTOR );
        }
    }
#endif
#endif
#endif
#endif
    while ( WordCount-- )
    {
        VerifyStatus = FlashVerifyWord( Address, BLANK_WORD );
        if ( VerifyStatus )
            return( Address );			// Return Address (!= 1) of first not blank location
        else
            Address = Address + 4;				// 32bit Word increment
    }
    return( VerifyStatus = 1 );					// Return 1 if all blank
}


unsigned long FlashGetBlankSector( void )
{
    unsigned long Address = 0;
    unsigned long WordCount = 0;
    int Sector;
    unsigned long BlankStatus = 0;
    unsigned long SectorFlag = 1;

    for ( Sector = 0; Sector <= FLASH_MAX_SECTORS; Sector++ )
    {
        switch ( Sector )
        {
        case 0:
            Address = BANK0_SECTOR0_START; WordCount = BANK0_SECTOR0_WORDCOUNT; break;
        case 1:
            Address = BANK0_SECTOR1_START; WordCount = BANK0_SECTOR1_WORDCOUNT; break;
        case 2:
            Address = BANK0_SECTOR2_START; WordCount = BANK0_SECTOR2_WORDCOUNT; break;
        case 3:
            Address = BANK0_SECTOR3_START; WordCount = BANK0_SECTOR3_WORDCOUNT; break;
        case 4:
            Address = BANK0_SECTOR4_START; WordCount = BANK0_SECTOR4_WORDCOUNT; break;
        case 5:
            Address = BANK0_SECTOR5_START; WordCount = BANK0_SECTOR5_WORDCOUNT; break;
#ifndef Flash_Size1
        case 6:
            Address = BANK0_SECTOR6_START; WordCount = BANK0_SECTOR6_WORDCOUNT; break;
        case 7:
            Address = BANK0_SECTOR7_START; WordCount = BANK0_SECTOR7_WORDCOUNT; break;
#ifndef Flash_Size2
        case 8:
            Address = BANK0_SECTOR8_START; WordCount = BANK0_SECTOR8_WORDCOUNT; break;
        case 9:
            Address = BANK0_SECTOR9_START; WordCount = BANK0_SECTOR9_WORDCOUNT; break;
        case 10:
            Address = BANK1_SECTOR0_START; WordCount = BANK1_SECTOR0_WORDCOUNT; break;
        case 11:
            Address = BANK1_SECTOR1_START; WordCount = BANK1_SECTOR1_WORDCOUNT; break;
#ifndef Flash_Size3
        case 12:
            Address = BANK2_SECTOR0_START; WordCount = BANK2_SECTOR0_WORDCOUNT; break;
        case 13:
            Address = BANK2_SECTOR1_START; WordCount = BANK2_SECTOR1_WORDCOUNT; break;
        case 14:
            Address = BANK2_SECTOR2_START; WordCount = BANK2_SECTOR2_WORDCOUNT; break;
#ifndef Flash_Size5
        case 15:
            Address = BANK3_SECTOR0_START; WordCount = BANK3_SECTOR0_WORDCOUNT; break;
        case 16:
            Address = BANK3_SECTOR1_START; WordCount = BANK3_SECTOR1_WORDCOUNT; break;
#endif
#endif
#endif
#endif
        default:
            break;
        }

        while ( WordCount-- )
        {
            if ( FlashVerifyWord( Address, BLANK_WORD ) )
            {
                BlankStatus = BlankStatus + ((unsigned long)1 << Sector );
                break;						// No need to look further in this Sector
            }
            Address = Address + 4;					// 32bit Word increment
        }
    }
    return( BlankStatus );					// Return 0 if all blank
}


/****************************************/
/*	FLASH CONTROL & STATUS FUNCTIONS	*/
/****************************************/

/****************************************************/
/*	Suspend / Resume functions						*/
/****************************************************/
unsigned int FlashSuspend( void )
{
    unsigned int temp;
    FCR0H = FCR0H | F_susp;			/* Set Suspend bit	*/

    /* Wait for the LOCK bit to CLEAR	*/
    WAIT_FOR_UNLOCK

    /* Wait for WMS bit to be cleared in FCR0H register	*/
    do{
        temp = FCR0H;
        temp = temp & F_wms;
    } while ( temp );
    return( FlashGetStatus() );
}

unsigned int FlashResume( void )
{
    FCR0H = FCR0H & ~F_susp;				// Clear Suspend bit
    // Wait for the LOCK bit to CLEAR
    WAIT_FOR_UNLOCK

    FCR0H = FCR0H | F_wms;				// Set back the Write Mode Start bit to resume
    return( FlashGetStatus() );
}


/******************************************************************************/
// Wait for a Flash operation to complete or a FLASH_TIMEOUT to occur
// If
//  The operation does not complete successfully
// Then
//  Return the appropriate ERROR code
/******************************************************************************/
unsigned int FlashWait( unsigned long Timeout )
{
    unsigned int Status;

    while ( ((Status = FlashGetStatus()) == FLASH_OPERATION_IN_PROGRESS) && Timeout-- )
    {
        FlashDelay();
    }

    if ( !Timeout )                   Status = FLASH_TIMEOUT;
    else if ( Status == FLASH_ERROR ) Status = FlashGetError();

    return( Status );
}


/******************************************************************************/
// Check the Flash status
// If
//   Flash ERROR occurred
// Then
//   Return FLASH_ERROR
// Else
//   Determine if a Flash operation is ongoing
//   Return status code (FLASH_OPERATION_: COMPLETE or IN_PROGRESS or SUSPENDED)
/******************************************************************************/
unsigned int FlashGetStatus()
{
    unsigned int Status;

    // Wait for the LOCK bit to CLEAR
    //WAIT_FOR_UNLOCK

    // Check if an operation is ongoing
#ifdef Flash_Size1
    Status = (FCR0L & F_bsy0) | (FCR0H & F_wms);
#endif
#ifdef Flash_Size2
    Status = (FCR0L & F_bsy0) | (FCR0H & F_wms);
#endif
#ifdef Flash_Size3
    Status = (FCR0L & (F_bsy0 | F_bsy1)) | (FCR0H & F_wms);
#endif
#ifdef Flash_Size5
    Status = (FCR0L & (F_bsy0 | F_bsy1 | F_bsy2)) | (FCR0H & F_wms);
#endif
#ifdef Flash_Size6
    Status = FCR0L & (F_bsy0 | F_bsy1 | F_bsy2 | F_bsy3) | (FCR0H & F_wms);
#endif
#ifdef F286
    Status = FCR0L & (F_bsy0 | F_bsy1 | F_bsy2 | F_bsy3) | (FCR0H & F_wms);
#endif

    if ( Status )
    {
        Status = FLASH_OPERATION_IN_PROGRESS;
    }
    else
    { // We must check for suspend mode
        if ( FCR0H & F_susp )
        {
            Status = FLASH_OPERATION_SUSPENDED;
        }
        else
        { // Check for an ERROR
            if ( FER & (F_err | F_erer | F_pger | F_10er | F_seqer | F_reser | F_wpf) )
            {
                Status = FLASH_ERROR;
            }
            else
            {
                Status = FLASH_OPERATION_COMPLETE;
            }
        }
    }
    return( Status );
}

/******************************************************************************/
// Determine the cause of a Flash ERROR
// Clear all ERROR Bits
/******************************************************************************/
unsigned int FlashGetError()
{
    unsigned int Status;

    // Determine the nature of the ERROR
    if ( FER & F_erer )		Status = FLASH_ERASE_ERROR;
    else if ( FER & F_pger )	Status = FLASH_PROGRAM_ERROR;
    else if ( FER & F_10er )	Status = FLASH_10_ERROR;
    else if ( FER & F_seqer)	Status = FLASH_SEQUENCE_ERROR;
    else if ( FER & F_reser)	Status = FLASH_RESUME_ERROR;
    else if ( FER & F_wpf )	Status = FLASH_PROTECTED_ERROR;
    else if ( FER & F_err )	Status = FLASH_WRITE_ERROR;
    else                    Status = FLASH_NO_ERROR_FOUND;

    // Clear all ERROR Bits
    FER = FER & ( (unsigned int)~(F_err | F_erer | F_pger | F_10er | F_seqer | F_reser | F_wpf) );

    return( Status );
}

/********************************/
/*	MISCELLANEOUS FUNCTIONS		*/
/********************************/

/******************************************************************************/
// The purpose of this routine is to provide a calibrated 5usec Delay,
// Which is independent of the application software/timers
/******************************************************************************/
void FlashDelay()
{
    int i;
    for ( i=0;(i < FLASH_DELAY_5USEC); i++ );
}



/******************************************************************************/
