/****************************************************************************
*																			*
* HEADER_START                                                        		*
*                                                                     		*
*		Name:           ST10 Flash drivers for the 0.18um devices      		*
*		Project:                                                       		*
*		Description:    Definition of the Flash control registers      		*
*		Processor:      ST10F27x, F29x, F25x                            	*
*		HW:                                                            		*
*		Revision:       1.4                                           		*
*		Date:           May, 2004                                      		*
*		Compiler:       C crosscompiler Tasking V8.0r2                 		*
*						C crosscompiler Keil uVision2 v2.36					*
*																			*
*		Author:         C. A.                                      			*
*		Company:        ST Microelectronics                            		*
*		                France												*
*		Security:       													*
*																			*
*		Contact:		st10.support@st.com									*
*						http://www.stmcu.com                           		*
* ========================================================================= *
* Copyright (c):      ST Microelectronics.,2004, All rights reserved. 		*
*                                                                     		*
* ========================================================================= *
*
* HEADER_END
*/
#ifndef _FLASH_H
#define _FLASH_H


/******************************************************************************/
// Useful Public Definitions
/******************************************************************************/

// Calibrated 5USEC Loop Time(Aproximate)
#define FLASH_DELAY_5USEC                  ((unsigned int)( 5 * Fcpu_MHz / 6))

// Delay Times in 5usec Increments
#define FLASH_DELAY_50USEC				((unsigned long)10)
#define FLASH_DELAY_100USEC				((unsigned long)20)
#define FLASH_DELAY_400USEC				((unsigned long)	80)
#define FLASH_DELAY_800USEC				((unsigned long)	160)
#define FLASH_DELAY_5SEC				((unsigned long)1000000 )
#define	FLASH_DELAY_8SEC				((unsigned long)1600000)
#define FLASH_DELAY_10SEC				((unsigned long)2000000 )
#define FLASH_DELAY_30SEC				((unsigned long)6000000)


// Flash Operations Definitions
#define FLASH_OPERATION_IN_PROGRESS		1
#define FLASH_OPERATION_COMPLETE		0
#define FLASH_OPERATION_SUSPENDED		2

// Flash Error Definitions
#define FLASH_ERROR						0xBAD0
#define FLASH_WRITE_ERROR				0xBAD1
#define	FLASH_10_ERROR					0xBAD2
#define	FLASH_PROGRAM_ERROR				0xBAD3
#define	FLASH_ERASE_ERROR				0xBAD4
#define	FLASH_NO_ERROR_FOUND			0xBAD5
#define	FLASH_TIMEOUT					0xBAD6
#define	FLASH_SEQUENCE_ERROR			0xBAD7
#define FLASH_RESUME_ERROR				0xBAD8
#define	FLASH_PROTECTED_ERROR			0xBAD9
#define FLASH_INVALID_BANK				0xBADA
#define	FLASH_INVALID_SECTOR			0xBADB
#define	VERIFY_ERROR					0xBADC
#define	FLASH_INVALID_ADDRESS			0xBADD

/******************************************************************************/
// Macros
/******************************************************************************/

#define WAIT_FOR_UNLOCK while( FCR0L & F_lock );

/******************************************************************************/
// Flash Procedure Prototypes
/******************************************************************************/

void			FlashDelay( void );
unsigned int	FlashWait( unsigned long Timeout );
unsigned int	FlashGetStatus( void );
unsigned int	FlashGetError( void );

/* Generic Functions with auto-selection of the Flash module */
void	FlashBankErase( int Bank );
void	FlashSectorErase( int Bank, int Block );
void	FlashMultiSectorErase( int Bank, int BlockMask );

unsigned int FlashProgramWord( unsigned long Address, unsigned long Data );
unsigned int FlashProgramDoubleWord( unsigned long Address, unsigned long Data1, unsigned long Data2 );
unsigned int FlashProgramRange( unsigned long Destination, unsigned long Source, unsigned long WordCount );
unsigned int FlashProgramPattern( unsigned long Destination, unsigned long WordCount, unsigned long Pattern );

unsigned int FlashVerifyWord( unsigned long Address, unsigned long Data);
unsigned int FlashVerifyDoubleWord( unsigned long Address, unsigned long Data1, unsigned long Data2);

/*		Returns the Address of the first not correct	*/
/*	 location or returns 0x1 if operation successful	*/
unsigned long FlashVerifyRange( unsigned long Source, unsigned long Destination, unsigned long WordCount);
/*		Returns the Address of the first not correct	*/
/*	 location or returns 0x1 if operation successful	*/
unsigned long FlashVerifyPattern( unsigned long Source, unsigned long WordCount, unsigned long Pattern);

/*		Returns the Address of the first not correct	*/
/*	 location or returns 0x1 if operation successful	*/
unsigned long FlashModuleBlankCheck( void );

/*		Returns the Address of the first not correct	*/
/*	 location or returns 0x1 if operation successful	*/
unsigned long FlashBankBlankCheck( int Bank );

/*		Returns the Address of the first not correct	*/
/*	 location or returns 0x1 if operation successful	*/
unsigned long FlashSectorBlankCheck( int Bank, int Sector );

/*		Set in a long the bits corresonding to the not	*/
/*	blank Sectors. Returns 0x0 if operation successful	*/
unsigned long FlashGetBlankSector( void );

/*		Suspend Flash on going operation				*/
/* Wait for the suspend to be active and returns Status	*/
unsigned int FlashSuspend( void );

/*		Resume a Flash operation. Calls the				*/
/* FlashGetStatus function and then returns				*/
unsigned int FlashResume( void );

/******************************************************************************/
#endif