


#include "asc.h"

/*******************************************************************************
* 	Function    :		void ASC_Init(  void )
*	Description :   	This function configures the ASC as follow:
*					    - 8 bit Asynchonous communication with no parity
*				     	- 1 stop bit
*					    - No errors check
*					    - Receiver is enabled
*					    - Baudrate 9600
*	Inputs      : 		None.
*   Output      :       None.
*	Return      :   	None.
*******************************************************************************/
void ASCInitialize ( void)
{
    /* Select 8-bit asynchronous communication; no parity, with no errors checking */
    /*	and receiver enable	*/
    S0CON = 0x8011;
    /* Baudrate 9600, FCPU = 40 MHZ. */
    S0BG = 0x0081;
    /*Tx0 : P3.10 -> output direction , Rx0: P3.11 -> Input direction */
    DP3 |= 0x0400;
#ifdef Tasking
    _nop();
#endif
#ifdef Keil
    _nop_();
#endif

    P3  |= 0x0400;
    /* Set the S0TBIR to trigger the transmission */
    S0TBIR = 1;
}



/*******************************************************************************
* 	Function    :		ASCSendByte
*	Description :   	Send a 8-bit data
*	Inputs      : 		8 bit data.
*   Output      :       None.
*	Return      :   	None.
*******************************************************************************/

void ASCSendByte( unsigned char data)
{
    while ( !S0TBIR );
    S0TBIR = 0;
    S0TBUF = data;
}



