/******************** (C) COPYRIGHT 2006 STMicroelectronics ********************
* File Name          : eeprom.h
* Author             : MCD Application Team
* Date First Issued  : 12/06/06 : Eprom Emulation Version 1.0
* Description        : This file provides the routines' prototypes and the variables 
*                      used in the eeprom.c source file.
********************************************************************************
* History:
* 12/06/06 : Eprom Emulation Version 1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/
#ifndef __EEPROM_H
#define __EEPROM_H

#define Tasking 

#include "F27x_flash.h"
#include "flash.h"

#ifdef Tasking
#include <reg276.h>
#endif 
#ifdef Keil
#include<ST10F276.h>
#endif
#include"stdio.h"


/* Sector size */
#define SECTOR_SIZE	(u32) (0x2000)	     
/* Sectors 0 and 1 base and end addresses */ 
#define SECTOR1_BASE_ADDRESS 0x2000;
#define SECTOR1_END_ADDRESS  0x3FFF;
#define SECTOR2_BASE_ADDRESS 0x4000;
#define SECTOR2_END_ADDRESS  0x5FFF;



/* Variables number (max_varia)should be entered by the programmer with respecting the sector size. */
#define max_varia (u8)(0x3)	  /* variables' number */

 
/* Sector status definitions */
#define ERASED				0xFFFFFFFF	 /* The sector is empty */
#define RECEIVE_DATA 		0xEEEEEEEE	 /* The sector is marked to receive data */
#define	VALID_SECTOR		0xCCCCCCCC	 /* sector containing valid data */
#define TRANSFER_COMPLETE	0x88888888	 /* data transfer from a full setcor to an another erased is completed. 
                                            After transfer is completed, the full sector is designed as TRANSFER_COMPLETE and 
                                            it will be erased after designing the new sector as VALID_SECTOR */

#define SECTOR1	(u8)(0x01)
#define SECTOR2	(u8)(0x02)
#define No_Valid_Sector (u8)(0xAB) 

/* Some other needed definitions */
#define VARIABLE_FULL				0x80
#define READ_FROM_VALID_SECTOR	    0x00
#define WRITE_IN_VALID_SECTOR       0x01
#define VARIABLE_EMPTY              0xFFFF 

typedef unsigned char 	u8; 				/*unsigned 8 bit type definition*/
typedef unsigned short 	u16; 				/*unsigned 16 bit type definition*/
typedef signed short 	s16; 				/*signed 16 bit type definition*/
typedef unsigned long 	u32; 				/*unsigned 32 bit type definition*/

/* Routines' prototypes */
u16 EepromFormat(void) ;
u8 FindValidSector(u8 operation);
u32 FlashRead(u32 Address);
u16 EepromSectorTransfer(u8 index, u32 *T,u32 data)	; 
u16 WriteVerifyVariableFull(u8 index, u32 *T, u32 Data);
u16 WriteVariable(u8 index, u32 *T,u32 data);
u32 ReadVariable(u8 index, u32 *T);

#endif

/************************ (c) 2005  ST Microelectronics ******* END OF FILE ***/